@@ -50,9 +50,6 @@ use Carp;
 
 use Symbol ();
 
-use Data::Dumper;
-$Data::Dumper::Indent = 1;
-
 use Net::Nmsg::Util qw( :io :vendor :sniff :channel :alias DEBUG );
 use Net::Nmsg::Input;
 use Net::Nmsg::Output;
@@ -211,7 +208,6 @@ sub loop {
   my $xs = $self->_xs;
   $xs->loop();
   $self->_init;
-  $self;
 }
 
 ### io wraps
@@ -219,12 +215,10 @@ sub loop {
 sub _wrap_io {
   my $self = shift;
   my($io, %opt) = @_;
-  #print STDERR "WRAP IO HERE: ", Dumper($io, \%opt);
   my $callbacks = $self->_callbacks;
   if (my $close_cb = $opt{close_cb}) {
     $callbacks->{$io} = sub {
       my $close_type = shift;
-      #print STDERR "  SPEC: $io : ", $io->_spec, "\n";
       return \0 if $close_type == NMSG_CLOSE_TYPE_EOF;
       my $old_xs = $io->_xs;
       $close_cb->($io);
@@ -288,7 +282,7 @@ sub add_input  {
     $self->add_input_sock($io, @_);
   }
   elsif (is_channel($io)) {
-    $self->add_channel_input($io, @_);
+    $self->add_input_channel($io, @_);
   }
   else {
     $self->_add_input_io($self->IO_INPUT->open($io, @_), @_);
@@ -356,7 +350,10 @@ sub add_output  {
   my $io   = shift;
   return $self->_add_output_io($io, @_) if $self->_is_io($io);
   if (! ref $io && expand_socket_spec($io)) {
-    $self->add_output_nmsg($io, @_);
+    $self->add_output_sock($io, @_);
+  }
+  elsif (is_channel($io)) {
+    $self->add_output_channel($io, @_);
   }
   else {
     $self->_add_output_io($self->IO_OUTPUT->open($io, @_), @_);
@@ -368,7 +365,7 @@ sub add_output_channel {
   my $chan = shift;
   my @sock = channel_lookup($chan);
   croak "not a channel '$chan'" unless @sock;
-  $self->add_output_nmsg($_, @_) foreach @sock;
+  $self->add_output_sock($_, @_) foreach @sock;
 }
 *add_output_chalias = \&add_output_channel;
 
@@ -626,7 +623,7 @@ message objects.
 
 =head1 SEE ALSO
 
-L<Net::Nmsg::Input>, L<Net::Nmsg::Output>, L<Net::Nmsg::Msg>, L<nmsgtool(1)>
+L<Net::Nmsg>, L<Net::Nmsg::Input>, L<Net::Nmsg::Output>, L<Net::Nmsg::Msg>, L<nmsgtool(1)>
 
 =head1 AUTHOR
 
