@@ -117,8 +117,9 @@ sub _map_opts {
   my %opt  = @_;
   my $vendor  = delete $opt{filter_vendor};
   my $msgtype = delete $opt{filter_msgtype};
-  return %opt unless defined $vendor || defined $msgtype;
-  $opt{filter_msgtype} = [$vendor, $msgtype];
+  if (defined $vendor || defined $msgtype) {
+    $opt{filter_msgtype} = [$vendor, $msgtype];
+  }
   %opt;
 }
 
@@ -391,7 +392,7 @@ Promiscuous mode (live interface only)
 
 =item open_file($spec, %options)
 
-Opens an input in nmsg format, as specified by file name, file handle.
+Opens an input in nmsg format, as specified by file name or file handle.
 
 =item open_sock($spec, %options)
 
@@ -468,7 +469,7 @@ many messages have been returned via the callback.
 
 =head1 SEE ALSO
 
-L<Net::Nmsg::IO>, L<Net::Nmsg::Output>, L<Net::Nmsg::Msg>, L<nmsgtool(1)>
+L<Net::Nmsg>, L<Net::Nmsg::IO>, L<Net::Nmsg::Output>, L<Net::Nmsg::Msg>, L<nmsgtool(1)>
 
 =head1 AUTHOR
 
