@@ -164,7 +164,7 @@ sub operator {
     $self->_unpack;
   }
   my($k, $v) = operator_lookup($self->[OPR]);
-  $v || '<UNKNOWN>';
+  $v;
 }
 
 sub group {
@@ -178,7 +178,7 @@ sub group {
     $self->_unpack;
   }
   my($k, $v) = group_lookup($self->[GRP]);
-  $v || '<UNKNOWN>';
+  $v;
 }
 
 sub time {
@@ -224,7 +224,10 @@ sub headers_as_str {
   push(@str, $src ? sprintf("[%08x]", $src) : '[]');
   join(' ',
     @str,
-    map { $_ ? "[$_]" : '[]' } ($msg->get_operator, $msg->get_group)
+    map { $_ ? "[$_]" : '[]' } (
+      $msg->get_operator || "<UNKNOWN>",
+      $msg->get_group    || "<UNKNOWN>"
+    )
   );
 }
 
@@ -312,7 +315,7 @@ sub _getter {
       my $fval = $unp->[$idx];
       if (!$fval || !@$fval) {
         $fval = [];
-        @$fval = $class->_class_msg->get_field_by_idx($idx);
+        @$fval = $class->_class_msg->get_field_vals_by_idx($idx);
       }
       if ($mapper) {
         @val = map { $mapper->($_, $class) } @$fval;
@@ -626,7 +629,7 @@ perl types for them:
 
 =head1 SEE ALSO
 
-L<Net::Nmsg::IO>, L<Net::Nmsg::Input>, L<Net::Nmsg::Output>, L<Net::WDNS>, L<nmsgtool(1)>
+L<Net::Nmsg>, L<Net::Nmsg::IO>, L<Net::Nmsg::Input>, L<Net::Nmsg::Output>, L<Net::WDNS>, L<nmsgtool(1)>
 
 =head1 AUTHOR
 
