@@ -100,9 +100,20 @@ sub set_source         { shift->_set_xs_opt(source         => @_) }
 sub set_group          { shift->_set_xs_opt(group          => @_) }
 sub set_buffered       { shift->_set_xs_opt(buffered       => @_) }
 sub set_zlibout        { shift->_set_xs_opt(zlibout        => @_) }
-sub set_rate           { shift->_set_xs_opt(rate           => @_) }
 sub set_endline        { shift->_set_xs_opt(endline        => @_) }
 
+sub set_rate {
+  my $self = shift;
+  my($rate, $freq);
+  if (@_ == 1 && ref $_[0]) {
+    ($rate, $freq) = @{$_[0]};
+  }
+  else {
+    ($rate, $freq) = @_;
+  }
+  $self->_set_xs_opt(rate => $rate, $freq)
+}
+
 ###
 
 sub is_file { (shift->_xs || return)->is_file }
@@ -115,16 +126,16 @@ sub is_cb   { (shift->_xs || return)->is_cb   }
 sub _map_opts {
   my $self = shift;
   my %opt  = @_;
-  my $vendor  = delete $opt{filter_vendor};
-  my $msgtype = delete $opt{filter_msgtype};
-  return %opt unless defined $vendor || defined $msgtype;
-  $self->error("vendor and msgtype required") && return
-    unless defined $vendor && defined $msgtype;
-  $opt{filter_msgtype} = [$vendor, $msgtype];
-  #
   my $rate = delete $opt{rate};
   my $freq = delete $opt{freq};
   $opt{rate} = [$rate, $freq];
+  my $vendor  = delete $opt{filter_vendor};
+  my $msgtype = delete $opt{filter_msgtype};
+  if (defined $vendor || defined $msgtype) {
+    $self->error("vendor and msgtype required")
+      unless defined $vendor && defined $msgtype;
+    $opt{filter_msgtype} = [$vendor, $msgtype];
+  }
   %opt;
 }
 
@@ -397,7 +408,7 @@ Write the given Net::Nmsg::Msg object to this output.
 
 =head1 SEE ALSO
 
-L<Net::Nmsg::IO>, L<Net::Nmsg::Input>, L<Net::Nmsg::Msg>, L<nmsgtool(1)>
+L<Net::Nmsg>, L<Net::Nmsg::IO>, L<Net::Nmsg::Input>, L<Net::Nmsg::Msg>, L<nmsgtool(1)>
 
 =head1 AUTHOR
 
